@@ -1,10 +1,14 @@
 colourise <- function(text, as = c("success", "skip", "warning", "failure", "error")) {
-  colour_config <- getOption("testthat.use_colours", TRUE)
-  if (!isTRUE(colour_config)) {
-    return(text)
+  if (has_colour()) {
+    unclass(cli::make_ansi_style(testthat_style(as))(text))
+  } else {
+    text
   }
+}
 
-  crayon::style(text, testthat_style(as))
+has_colour <- function() {
+  isTRUE(getOption("testthat.use_colours", TRUE)) &&
+    cli::num_ansi_colors() > 1
 }
 
 testthat_style <- function(type = c("success", "skip", "warning", "failure", "error")) {
@@ -14,7 +18,7 @@ testthat_style <- function(type = c("success", "skip", "warning", "failure", "er
     success = "green",
     skip = "blue",
     warning = "magenta",
-    failure = "red",
-    error = "red"
+    failure = "orange",
+    error = "orange"
   )[[type]]
 }
