@@ -1,6 +1,3 @@
-#' @include reporter.R
-NULL
-
 #' Test reporter: RStudio
 #'
 #' This reporter is designed for output to RStudio. It produces results in
@@ -8,25 +5,24 @@ NULL
 #'
 #' @export
 #' @family reporters
-RstudioReporter <- R6::R6Class("RstudioReporter",
+RStudioReporter <- R6::R6Class("RStudioReporter",
   inherit = Reporter,
   public = list(
+    initialize = function(...) {
+      self$capabilities$parallel_support <- TRUE
+      super$initialize(...)
+    },
+
     add_result = function(context, test, result) {
       if (expectation_success(result)) {
         return()
       }
 
-      ref <- result$srcref
-      if (is.null(ref)) {
-        location <- "?#?:?"
-      } else {
-        location <- paste0(attr(ref, "srcfile")$filename, "#", ref[1], ":1")
-      }
-
+      loc <- expectation_location(result)
       status <- expectation_type(result)
       first_line <- strsplit(result$message, "\n")[[1]][1]
 
-      self$cat_line(location, " [", status, "] ", test, ". ", first_line)
+      self$cat_line(loc, " [", status, "] ", test, ". ", first_line)
     }
   )
 )
